<div class="card">
    <h5 class="card-header">Linux Volumes</h5>
    <div class="card-body">
        {% if lvm_list %}
        <table class="table table-hover">
            <tr>
                <td>Volume Name</td>
                <td>Filesystem</td>
                <td>Mount Path</td>
                <td>Volume Size</td>
                <td>Partition Name</td>
                <td>Partition Type</td>
                <td>Partition Size</td>
                <td>Drive Identifier</td>
            </tr>
            {% for lvm in lvm_list %}
            <tr>
                <td>lvm.lv_name</td>
                <td>lvm.path</td>
                <td>lvm.fs</td>
                <td>lvm.vg_name</td>
            </tr>
            {% endfor %}
        </table>
        {% else %}
        <div class="text-muted">None</div>
        {% endif %}
    </div>
    <div class="card-footer text-end noprint">
        <a href="{% url 'plugins:netbox_storage:drive_add' %}" class="btn btn-sm btn-primary">
            <span class="mdi mdi-plus-thick" aria-hidden="true"></span> Add Drive
        </a>
    </div>
</div>